@@ -3,7 +3,7 @@
 import os
 
 from jmapc import Client
-from jmapc.methods import IdentityGet
+from jmapc.methods import IdentityGet, IdentityGetResponse
 
 # Create and configure client
 client = Client.create_with_api_token(
@@ -18,6 +18,7 @@ method = IdentityGet()
 result = client.request(method)
 
 # Print some information about each retrieved identity
+assert isinstance(result, IdentityGetResponse), "Error in Identity/get method"
 for identity in result.data:
     print(
         f"Identity {identity.id} is for "
