@@ -1,11 +1,12 @@
 from . import auth, errors, fastmail, methods, models
 from .__version__ import __version__ as version
-from .client import Client, EventSourceConfig
+from .client import Client, ClientError, EventSourceConfig
 from .errors import Error
 from .methods import Request, ResponseOrError
 from .models import (
     AddedItem,
     Address,
+    Blob,
     Comparator,
     Delivered,
     DeliveryStatus,
@@ -44,7 +45,9 @@ from .ref import Ref, ResultReference
 __all__ = [
     "AddedItem",
     "Address",
+    "Blob",
     "Client",
+    "ClientError",
     "Comparator",
     "Delivered",
     "DeliveryStatus",
