@@ -9,11 +9,11 @@ from .models import EmailAddress
 
 @dataclass
 class Identity(Model):
-    id: str
     name: str
     email: str
-    replyTo: Optional[str]
+    reply_to: Optional[str]
     bcc: Optional[List[EmailAddress]]
-    textSignature: Optional[str]
-    htmlSignature: Optional[str]
-    mayDelete: bool
+    text_signature: Optional[str]
+    html_signature: Optional[str]
+    may_delete: bool
+    id: Optional[str] = None
