@@ -15,6 +15,13 @@ ListOrRef = Union[List[T], ResultReference, Ref]
 TypeOrRef = Union[T, ResultReference, Ref]
 
 
+@dataclass
+class Blob(Model):
+    id: str = field(metadata=config(field_name="blobId"))
+    type: str
+    size: int
+
+
 @dataclass
 class AddedItem(Model):
     id: str = field(metadata=config(field_name="id"))
@@ -54,3 +61,6 @@ class Operator(Enum):
 class SetError(Model):
     type: str
     description: Optional[str] = None
+    already_exists: Optional[str] = None
+    not_found: Optional[List[str]] = None
+    properties: Optional[List[str]] = None
